@@ -3,4 +3,6 @@
 from .models import Target
 from .models import Config
 from .models import Category
+from .models import IP
 from .models import Organization
+from .models import Port
